# harborapi.models._scanner

These models have been generated from the official Harbor Pluggable Scanner Spec [OpenAPI 3.0 Schema](https://github.com/goharbor/pluggable-scanner-spec/blob/master/api/spec/scanner-adapter-openapi-v1.1.yaml) using [datamodel-code-generator](https://koxudaxi.github.io/datamodel-code-generator/) version 0.13.0.

::: harborapi.models._scanner
    options:
        show_if_no_docstring: true
        show_source: true
        show_bases: false
